==> segatex-8.500.tar.gz: segatex-8.500/src/segatex_core.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <q3textedit.h>
#include <q3process.h>
//Added by qt3to4:
#include <Q3VBoxLayout>
#include <Q3HBoxLayout>

#include "segatex_core.h"
#include "segatex_core_process.h"
#include "segatex_core2_process.h"

//for debug
//#include <iostream>
//using namespace std;

//default constructor
SegatexCore::SegatexCore(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("Analize audit.log"));
		segatex_coreButton = new QPushButton(tr("&denied_log"), this);
		segatex_core2Button = new QPushButton(tr("&generate policy"), this);
		closeButton = new QPushButton(tr("&Close"), this);
		segatex_coreButton->setDefault(true);

		connect(segatex_coreButton, SIGNAL(clicked()), this, SLOT(segatex_core_clicked()));
		connect(segatex_core2Button, SIGNAL(clicked()), this, SLOT(segatex_core2_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		Q3VBoxLayout *leftLayout = new Q3VBoxLayout;

		Q3VBoxLayout *rightLayout = new Q3VBoxLayout;
		rightLayout->addWidget(segatex_coreButton);
		rightLayout->addWidget(segatex_core2Button);

		Q3HBoxLayout *footLayout = new Q3HBoxLayout;
		footLayout->addStretch(1);
		footLayout->addWidget(closeButton);


		Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(leftLayout);
		mainLayout->addLayout(rightLayout);
		mainLayout->addLayout(footLayout);
		resize(200,100);

		//needs here to be declared for window newly opened unless segmentation fault occurs
		segatex_core_process = 0;
		segatex_core2_process = 0;
}
void SegatexCore::segatex_core_clicked()
{
	segatex_core_process = new SegatexCoreProcess(this);
	connect(segatex_core_process, SIGNAL(segatex_core_prosess_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), segatex_core_process, SLOT(close()));
	segatex_core_process->show();
	segatex_core_process->raise();
	segatex_core_process->setActiveWindow();
}
void SegatexCore::segatex_core2_clicked()
{
	segatex_core2_process = new SegatexCore2Process(this);
	connect(segatex_core2_process, SIGNAL(segatex_core2_prosess_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), segatex_core2_process, SLOT(close()));
	segatex_core2_process->show();
	segatex_core2_process->raise();
	segatex_core2_process->setActiveWindow();
}

==> segatex-8.520.tar.gz: segatex-8.520/src/segatex_core.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <q3textedit.h>
//Added by qt3to4:

#include "segatex_core.h"
#include "segatex_core_process.h"
#include "segatex_core2_process.h"

//for debug
//#include <iostream>
//using namespace std;

//default constructor
SegatexCore::SegatexCore(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("Analize audit.log"));
		segatex_coreButton = new QPushButton(tr("&denied_log"), this);
		segatex_core2Button = new QPushButton(tr("&generate policy"), this);
		closeButton = new QPushButton(tr("&Close"), this);
		segatex_coreButton->setDefault(true);

		connect(segatex_coreButton, SIGNAL(clicked()), this, SLOT(segatex_core_clicked()));
		connect(segatex_core2Button, SIGNAL(clicked()), this, SLOT(segatex_core2_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		leftLayout = new QVBoxLayout;

		rightLayout = new QVBoxLayout;
		rightLayout->addWidget(segatex_coreButton);
		rightLayout->addWidget(segatex_core2Button);

		footLayout = new QHBoxLayout;
		footLayout->addStretch(1);
		footLayout->addWidget(closeButton);


		mainLayout = new QVBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(leftLayout);
		mainLayout->addLayout(rightLayout);
		mainLayout->addLayout(footLayout);
		resize(200,100);

		//needs here to be declared for window newly opened unless segmentation fault occurs
		segatex_core_process = 0;
		segatex_core2_process = 0;
}
void SegatexCore::segatex_core_clicked()
{
	segatex_core_process = new SegatexCoreProcess(this);
	connect(segatex_core_process, SIGNAL(segatex_core_prosess_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), segatex_core_process, SLOT(close()));
	segatex_core_process->show();
	segatex_core_process->raise();
	segatex_core_process->setActiveWindow();
}
void SegatexCore::segatex_core2_clicked()
{
	segatex_core2_process = new SegatexCore2Process(this);
	connect(segatex_core2_process, SIGNAL(segatex_core2_prosess_close_button_clicked()), this, SLOT(close()));
	connect(closeButton, SIGNAL(clicked()), segatex_core2_process, SLOT(close()));
	segatex_core2_process->show();
	segatex_core2_process->raise();
	segatex_core2_process->setActiveWindow();
}
